@@ -3,10 +3,16 @@ try:
 except ImportError:
     __version__ = "unknown"
 
-from ._widget import batch_annotator, batch_predict, batch_training
+from ._widget import (
+    batch_annotator,
+    batch_predict,
+    batch_training,
+    batch_workflow,
+)
 
 __all__ = [
     "batch_annotator",
+    "batch_workflow",
     "batch_training",
     "batch_predict",
 ]
